:: ****************************************************** {COPYRIGHT-TOP} ***
:: Licensed Materials - Property of IBM
:: 5724-M07, 5698-A77
::
:: (C) Copyright IBM Corp. 2005 All Rights Reserved.
::
:: US Government Users Restricted Rights - Use, duplication, or
:: disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
:: ****************************************************** {COPYRIGHT-END} ***

::
:: Description:
::
::   This batch file creates a cabinet file containing the logs and
::   configuration files for KD4.  It leaves the cabinet file in the working
::   directory where the batch file was invoked from.  The file name is in
::   the form:
::
::     KD4PDDC.<date>.<time>.CAB
::
::   To reconstitute the files into the current directory (or to any directory
::   by replacing the rightmost dot with a directory name), issue the following
::   command:
::
::     expand KD4PDDC.<date>.<time>.CAB -F:* .
::

@echo off

set ERRORLEVEL=0
set KD4_RC=0

::--------------------------------------------------------------------
:: The definition of where KD4 is installed lives here.  Parse it out.
::--------------------------------------------------------------------
set KD4_HOME_PROPFILE=%SYSTEMROOT%\system32\drivers\etc\KD4BaseDirConfig.properties

:find_kd4_home

:: Check if KD4_HOME_PROPFILE exists
if exist %KD4_HOME_PROPFILE% goto kd4_home_dir_name_ok
echo Error: %KD4_HOME_PROPFILE% not found
set KD4_RC=111
goto done

:kd4_home_dir_name_ok

:: The following line sets INSTALLDIR_PROP to contents of the prop file
set /p INSTALLDIR_PROP= <  %KD4_HOME_PROPFILE%

:: The following line prepends the word "set" to the line read above
:: and writes the result to a temporary batch file
echo set %INSTALLDIR_PROP%> %TEMP%\KD4PDDCSET.BAT

call %TEMP%\KD4PDDCSET.BAT
rem del %TEMP%\KD4PDDCSET.BAT

::-----------------------------------
:: Trim double backslashes to singles
::-----------------------------------
set INSTALLDIR=%INSTALLDIR:\\=\%

::-------------------------------------------------------------------------
:: INSTALLDIR now contains the KD4 home dir location.  Make sure it exists.
::-------------------------------------------------------------------------
if exist "%INSTALLDIR%" goto kd4_home_dir_ok
if exist %INSTALLDIR% goto kd4_home_dir_ok

echo Error: "%INSTALLDIR%" not found.
set KD4_RC=111
goto done

:kd4_home_dir_ok

::--------------------------------
:: Construct the cabinet file name
::--------------------------------
set TIMESTAMP=%DATE:~-4%%DATE:~4,2%%DATE:~7,2%.%TIME:~0,2%%TIME:~3,2%%TIME:~6,2%
:: %TIME% Puts a leading space on hours if < 10, change to 0
set TIMESTAMP=%TIMESTAMP: =0%
set PDFILENAME=KD4PDDC.%TIMESTAMP%.CAB

::--------------------------------
:: Construct a cab definition file
::--------------------------------
echo .Set Cabinet=on> KD4PDDC.DDF
echo .Set Compress=on>> KD4PDDC.DDF
echo .Set CompressionType=LZX>> KD4PDDC.DDF
echo .Set CompressionMemory=21>> KD4PDDC.DDF
echo .Set CabinetNameTemplate=%PDFILENAME%>> KD4PDDC.DDF
echo .Set MaxDiskSize=CDROM>> KD4PDDC.DDF
echo .Set DiskDirectoryTemplate=CDROM >> KD4PDDC.DDF
echo .Set DiskDirectory1=%CD%>> KD4PDDC.DDF

::---------------------------------------------------------------------------------
:: Write a file containing environment information, add it to the bundle definition
::---------------------------------------------------------------------------------
echo Listing the directory tree of "%INSTALLDIR%\KD4\logs...
dir /A-D /s "%INSTALLDIR%\KD4\logs" >> %TEMP%\KD4PDDCEnv.txt
echo Listing the directory tree of "%INSTALLDIR%\KD4\config...
dir /A-D /s "%INSTALLDIR%\KD4\config" >> %TEMP%\KD4PDDCEnv.txt
:: Add it to the bundle
if exist %TEMP%\KD4PDDCEnv.txt echo %TEMP%\KD4PDDCEnv.txt >> kd4pddc.ddf

::-----------------------------
:: The files to bundle go here:
::-----------------------------
echo Building file list for cabinet file...
for /f "delims=" %%I in ('dir /A-D /b /s "%INSTALLDIR%\KD4\logs\*metric*" "%INSTALLDIR%\KD4\logs\*operations*" "%INSTALLDIR%\KD4\logs\*trace*" "%INSTALLDIR%\KD4\logs\*actions*" "%INSTALLDIR%\KD4\logs\*configNETDC*" "%INSTALLDIR%\logs\KD4RAS1.log"') do echo "%%I" >> kd4pddc.ddf
for /f "delims=" %%I in ('dir /A-D /b /s "%INSTALLDIR%\KD4\config"') do echo "%%I" >> kd4pddc.ddf
if exist %TEMP%\operations.log echo %TEMP%\operations.log >> kd4pddc.ddf
if exist %TEMP%\trace.log echo %TEMP%\trace.log >> kd4pddc.ddf
if exist %SystemRoot%\temp\operations.log echo %SystemRoot%\temp\operations.log >> kd4pddc.ddf
if exist %SystemRoot%\temp\trace.log echo %SystemRoot%\temp\trace.log >> kd4pddc.ddf
if exist "%INSTALLDIR%\KD4BLDID.txt" echo "%INSTALLDIR%\KD4BLDID.txt" >> kd4pddc.ddf
if exist "%INSTALLDIR%\KD4\bin\KD4.net.buildinfo.properties" echo "%INSTALLDIR%\KD4\bin\KD4.net.buildinfo.properties" >> kd4pddc.ddf
if exist "%INSTALLDIR%\logs\KD4RAS1.log" echo "%INSTALLDIR%\logs\KD4RAS1.log" >> kd4pddc.ddf

::----------------------------
:: Finally, build the cab file
::----------------------------
echo Building cabinet file.  This may take several minutes based on log file sizes.
makecab /f kd4pddc.ddf > kd4pddc.cab.out

::------------------------------------------
:: Check for failure/success of cab creation
::------------------------------------------
if exist %PDFILENAME% goto success
type kd4pddc.cab.out
echo Error: %PDFILENAME% failed to be created.  Please review kd4pddc.ddf and kd4pddc.cab.out files.
goto done

:success
::----------------------------------------------
:: Announce the location of the created CAB file
::----------------------------------------------
echo Success: %PDFILENAME% created in the current directory.

::----------------------------
:: Delete temporary work files
::----------------------------
del kd4pddc.ddf
del kd4pddc.cab.out
del setup.rpt
del setup.inf
goto done

:done
set ERRORLEVEL=%KD4_RC%
